@@ -917,14 +917,15 @@ int store_params() {
     }
 }
 
-bool ensure_var_space(int n) {
-    int nc = cwd->vars_count + n;
-    if (nc > cwd->vars_capacity) {
-        var_struct *nv = (var_struct *) realloc(cwd->vars, nc * sizeof(var_struct));
+bool ensure_var_space(int n, bool do_root) {
+    directory *dir = do_root ? root : cwd;
+    int nc = dir->vars_count + n;
+    if (nc > dir->vars_capacity) {
+        var_struct *nv = (var_struct *) realloc(dir->vars, nc * sizeof(var_struct));
         if (nv == NULL)
             return false;
-        cwd->vars_capacity = nc;
-        cwd->vars = nv;
+        dir->vars_capacity = nc;
+        dir->vars = nv;
     }
     return true;
 }
